Root

Struct Root 

pub struct Root { /* private fields */ }

Implementations

Source

impl Root

pub fn new( globals: &GlobalList, event_queue: &mut EventQueue<Root>, bar: Option<Bar>, ) -> Result<Root>

Examples found in repository?
examples/toml_config/main.rs (line 11)
5fn main() -> Result<()> {
6    let config = Config::parse_toml("./examples/toml_config/config.toml".into())?;
7
8    let conn = Connection::connect_to_env()?;
9    let (globals, mut event_queue) = registry_queue_init(&conn)?;
10
11    let mut capybar = Root::new(&globals, &mut event_queue, None)?;
12    capybar.apply_config(config)?;
13
14    capybar.run(&mut event_queue)?;
15
16    Ok(())
17}
More examples
Hide additional examples
examples/basic/main.rs (line 115)
21fn main() -> Result<(), Box<dyn std::error::Error>> {
22    let catpuccin_mocha = Palete {
23        background: Color::from_hex(0x1e1e2eff),
24        border: Color::from_hex(0x74c7ecff),
25        font: Color::from_hex(0xf5e0dcff),
26    };
27
28    let conn = Connection::connect_to_env()?;
29    let (globals, mut event_queue) = registry_queue_init(&conn)?;
30
31    let mut bar = Bar::new(
32        None,
33        BarSettings {
34            default_data: WidgetData {
35                width: 1920,
36                ..WidgetData::default()
37            },
38            padding: (10, 10, 10),
39
40            style: Style {
41                background: Some(catpuccin_mocha.background),
42                border: Some((1, catpuccin_mocha.border)),
43
44                ..Style::default()
45            },
46
47            ..BarSettings::default()
48        },
49    )?;
50
51    // Left widgets
52    bar.create_widget_left(
53        CPU::new,
54        CPUSettings {
55            update_rate: 1000,
56            text_settings: TextSettings {
57                font_color: catpuccin_mocha.font,
58                size: 25.0,
59
60                ..TextSettings::default()
61            },
62            default_data: WidgetData {
63                ..WidgetData::default()
64            },
65            style: Style {
66                margin: Margin {
67                    left: 10,
68                    right: 0,
69                    up: 0,
70                    down: 0,
71                },
72                ..Default::default()
73            },
74            ..CPUSettings::default()
75        },
76    )?;
77
78    //Center widgets
79    bar.create_widget_center(
80        Clock::new,
81        ClockSettings {
82            font_color: catpuccin_mocha.font,
83            size: 25.0,
84
85            ..ClockSettings::default()
86        },
87    )?;
88
89    // Right widgets
90    bar.create_widget_right(
91        Battery::new,
92        BatterySettings {
93            text_settings: TextSettings {
94                font_color: catpuccin_mocha.font,
95                size: 25.0,
96
97                ..TextSettings::default()
98            },
99            default_data: WidgetData {
100                ..WidgetData::default()
101            },
102            style: Style {
103                margin: Margin {
104                    left: 0,
105                    right: 10,
106                    up: 0,
107                    down: 0,
108                },
109                ..Default::default()
110            },
111            ..BatterySettings::default()
112        },
113    )?;
114
115    let mut capybar = Root::new(&globals, &mut event_queue, Some(bar))?;
116
117    // Fonts can be replaces by your liking. The first font added will be used for normal text, the
118    // second for emoji
119    //capybar.add_font_by_name("mono")?;
120    capybar.add_font_by_name("jetbrainsmononerdfont")?;
121    capybar.add_font_by_name("jetbrainsmononerdfont")?;
122
123    capybar.run(&mut event_queue)?;
124
125    Ok(())
126}
pub fn apply_config(&mut self, config: Config) -> Result<()>

Examples found in repository?
examples/toml_config/main.rs (line 12)
5fn main() -> Result<()> {
6    let config = Config::parse_toml("./examples/toml_config/config.toml".into())?;
7
8    let conn = Connection::connect_to_env()?;
9    let (globals, mut event_queue) = registry_queue_init(&conn)?;
10
11    let mut capybar = Root::new(&globals, &mut event_queue, None)?;
12    capybar.apply_config(config)?;
13
14    capybar.run(&mut event_queue)?;
15
16    Ok(())
17}
pub fn run(&mut self, event_queue: &mut EventQueue<Root>) -> Result<&mut Self>

Examples found in repository?
examples/toml_config/main.rs (line 14)
5fn main() -> Result<()> {
6    let config = Config::parse_toml("./examples/toml_config/config.toml".into())?;
7
8    let conn = Connection::connect_to_env()?;
9    let (globals, mut event_queue) = registry_queue_init(&conn)?;
10
11    let mut capybar = Root::new(&globals, &mut event_queue, None)?;
12    capybar.apply_config(config)?;
13
14    capybar.run(&mut event_queue)?;
15
16    Ok(())
17}
More examples
Hide additional examples
examples/basic/main.rs (line 123)
21fn main() -> Result<(), Box<dyn std::error::Error>> {
22    let catpuccin_mocha = Palete {
23        background: Color::from_hex(0x1e1e2eff),
24        border: Color::from_hex(0x74c7ecff),
25        font: Color::from_hex(0xf5e0dcff),
26    };
27
28    let conn = Connection::connect_to_env()?;
29    let (globals, mut event_queue) = registry_queue_init(&conn)?;
30
31    let mut bar = Bar::new(
32        None,
33        BarSettings {
34            default_data: WidgetData {
35                width: 1920,
36                ..WidgetData::default()
37            },
38            padding: (10, 10, 10),
39
40            style: Style {
41                background: Some(catpuccin_mocha.background),
42                border: Some((1, catpuccin_mocha.border)),
43
44                ..Style::default()
45            },
46
47            ..BarSettings::default()
48        },
49    )?;
50
51    // Left widgets
52    bar.create_widget_left(
53        CPU::new,
54        CPUSettings {
55            update_rate: 1000,
56            text_settings: TextSettings {
57                font_color: catpuccin_mocha.font,
58                size: 25.0,
59
60                ..TextSettings::default()
61            },
62            default_data: WidgetData {
63                ..WidgetData::default()
64            },
65            style: Style {
66                margin: Margin {
67                    left: 10,
68                    right: 0,
69                    up: 0,
70                    down: 0,
71                },
72                ..Default::default()
73            },
74            ..CPUSettings::default()
75        },
76    )?;
77
78    //Center widgets
79    bar.create_widget_center(
80        Clock::new,
81        ClockSettings {
82            font_color: catpuccin_mocha.font,
83            size: 25.0,
84
85            ..ClockSettings::default()
86        },
87    )?;
88
89    // Right widgets
90    bar.create_widget_right(
91        Battery::new,
92        BatterySettings {
93            text_settings: TextSettings {
94                font_color: catpuccin_mocha.font,
95                size: 25.0,
96
97                ..TextSettings::default()
98            },
99            default_data: WidgetData {
100                ..WidgetData::default()
101            },
102            style: Style {
103                margin: Margin {
104                    left: 0,
105                    right: 10,
106                    up: 0,
107                    down: 0,
108                },
109                ..Default::default()
110            },
111            ..BatterySettings::default()
112        },
113    )?;
114
115    let mut capybar = Root::new(&globals, &mut event_queue, Some(bar))?;
116
117    // Fonts can be replaces by your liking. The first font added will be used for normal text, the
118    // second for emoji
119    //capybar.add_font_by_name("mono")?;
120    capybar.add_font_by_name("jetbrainsmononerdfont")?;
121    capybar.add_font_by_name("jetbrainsmononerdfont")?;
122
123    capybar.run(&mut event_queue)?;
124
125    Ok(())
126}
pub fn add_font_by_name(&mut self, name: &'static str) -> Result<(), FontsError>

Examples found in repository?
examples/basic/main.rs (line 120)
21fn main() -> Result<(), Box<dyn std::error::Error>> {
22    let catpuccin_mocha = Palete {
23        background: Color::from_hex(0x1e1e2eff),
24        border: Color::from_hex(0x74c7ecff),
25        font: Color::from_hex(0xf5e0dcff),
26    };
27
28    let conn = Connection::connect_to_env()?;
29    let (globals, mut event_queue) = registry_queue_init(&conn)?;
30
31    let mut bar = Bar::new(
32        None,
33        BarSettings {
34            default_data: WidgetData {
35                width: 1920,
36                ..WidgetData::default()
37            },
38            padding: (10, 10, 10),
39
40            style: Style {
41                background: Some(catpuccin_mocha.background),
42                border: Some((1, catpuccin_mocha.border)),
43
44                ..Style::default()
45            },
46
47            ..BarSettings::default()
48        },
49    )?;
50
51    // Left widgets
52    bar.create_widget_left(
53        CPU::new,
54        CPUSettings {
55            update_rate: 1000,
56            text_settings: TextSettings {
57                font_color: catpuccin_mocha.font,
58                size: 25.0,
59
60                ..TextSettings::default()
61            },
62            default_data: WidgetData {
63                ..WidgetData::default()
64            },
65            style: Style {
66                margin: Margin {
67                    left: 10,
68                    right: 0,
69                    up: 0,
70                    down: 0,
71                },
72                ..Default::default()
73            },
74            ..CPUSettings::default()
75        },
76    )?;
77
78    //Center widgets
79    bar.create_widget_center(
80        Clock::new,
81        ClockSettings {
82            font_color: catpuccin_mocha.font,
83            size: 25.0,
84
85            ..ClockSettings::default()
86        },
87    )?;
88
89    // Right widgets
90    bar.create_widget_right(
91        Battery::new,
92        BatterySettings {
93            text_settings: TextSettings {
94                font_color: catpuccin_mocha.font,
95                size: 25.0,
96
97                ..TextSettings::default()
98            },
99            default_data: WidgetData {
100                ..WidgetData::default()
101            },
102            style: Style {
103                margin: Margin {
104                    left: 0,
105                    right: 10,
106                    up: 0,
107                    down: 0,
108                },
109                ..Default::default()
110            },
111            ..BatterySettings::default()
112        },
113    )?;
114
115    let mut capybar = Root::new(&globals, &mut event_queue, Some(bar))?;
116
117    // Fonts can be replaces by your liking. The first font added will be used for normal text, the
118    // second for emoji
119    //capybar.add_font_by_name("mono")?;
120    capybar.add_font_by_name("jetbrainsmononerdfont")?;
121    capybar.add_font_by_name("jetbrainsmononerdfont")?;
122
123    capybar.run(&mut event_queue)?;
124
125    Ok(())
126}
pub fn create_service<W, F>( &mut self, f: F, settings: W::Settings, ) -> Result<()>
where W: ServiceNew + Service + 'static, F: FnOnce(Option<Rc<Environment>>, W::Settings) -> Result<W, ServiceError>,

pub fn bar(&self) -> &Option<Bar>